Module: Ambit
- Defined in:
- lib/ambit.rb
Overview
This gem allows choose/fail (amb) style non-deterministic programming in Ruby
- Author
-
Jim Wise ([email protected])
- Copyright
-
Copyright © 2011 Jim Wise
- License
-
2-clause BSD-Style (see LICENSE)
Defined Under Namespace
Classes: ChoicesExhausted, Generator
Constant Summary collapse
- VERSION =
'0.10'- Default_Generator =
The default generator used by Ambit.choose, Ambit.fail!, et al. should not be used directly.
Generator.new
Class Method Summary collapse
-
.method_missing(sym, *args, &block) ⇒ Object
forward method invocations on this module to the default Generator.
Class Method Details
.method_missing(sym, *args, &block) ⇒ Object
forward method invocations on this module to the default Generator.
135 136 137 |
# File 'lib/ambit.rb', line 135 def Ambit::method_missing(sym, *args, &block) # :nodoc: Ambit::Default_Generator.send(sym, *args, &block) end |